@@ -14,7 +14,7 @@ WARNING: This program is based on xlrd and will therefore
 https://pypi.org/project/xlrd/
 """
 
-__version__ = "1.1.0"
+__version__ = "1.1.1"
 
 
 import os
@@ -426,8 +426,18 @@ def main(args=None):
 
 				out[old] = new
 
+	class PrintVersion(argparse.Action):
+
+		def __init__(self, option_strings, dest, **kwargs):
+			kwargs.setdefault('nargs', 0)
+			argparse.Action.__init__(self, option_strings, dest, **kwargs)
+
+		def __call__(self, parser, namespace, values, option_string=None):
+			print(__version__)
+			sys.exit(0)
+
 	p = argparse.ArgumentParser(description=__doc__, formatter_class=argparse.RawDescriptionHelpFormatter)
-	p.add_argument("-v", "--version", action="store_true", help="show the version number of this program and exit")
+	p.add_argument("-v", "--version", action=PrintVersion, help="show the version number of this program and exit")
 	p.add_argument("filename", help="The Excel file to read")
 	p.add_argument("worksheet", nargs='?', help="The name or number of the worksheet to export (optional if there is only one worksheet)")
 	p.add_argument("-c", "--columns", "--cols", metavar="COLS", default="*", help="The columns to export")
@@ -494,10 +504,6 @@ FMT:
 
 	args = p.parse_args(args)
 
-	if args.version:
-		print(__version__)
-		return
-
 	try:
 		ee = ExcelExporter(args.filename, args.worksheet,
 				directoryname_pattern=args.directory_pattern,
